package com.zd.laboratory.service;

import java.util.List;

import com.zd.common.core.domain.R;
import com.zd.laboratory.domain.LabNegativelistHistory;
import com.zd.laboratory.domain.vo.LabNegativelistVO;
import com.zd.laboratory.domain.vo.LabViolationPageListVO;

/**
 * 负面清单历史记录Service接口
 *
 * @author zd
 * @date 2021-12-17
 */
public interface ILabNegativelistHistoryService
{
    /**
     * 查询负面清单历史记录
     *
     * @param id 负面清单历史记录主键
     * @return 负面清单历史记录
     */
    public LabNegativelistHistory selectLabNegativelistHistoryById(Long id);

    /**
     * 查询负面清单历史记录列表
     *
     * @param labNegativelistHistory 负面清单历史记录
     * @return 负面清单历史记录集合
     */
    public List<LabNegativelistHistory> selectLabNegativelistHistoryList(LabNegativelistVO labNegativelistHistory);


    /**
     * 查询负面清单历史记录列表
     *
     * @param labNegativelistHistory 负面清单历史记录
     * @return 负面清单历史记录集合
     */
    public List<LabNegativelistHistory> myNegativelistHistoryList(LabNegativelistVO labNegativelistHistory);

    /**
     * 新增负面清单历史记录
     *
     * @param labNegativelistHistory 负面清单历史记录
     * @return 结果
     */
    public int insertLabNegativelistHistory(LabNegativelistHistory labNegativelistHistory);

    /**
     * 修改负面清单历史记录
     *
     * @param labNegativelistHistory 负面清单历史记录
     * @return 结果
     */
    public int updateLabNegativelistHistory(LabNegativelistHistory labNegativelistHistory);

    /**
     * 批量删除负面清单历史记录
     *
     * @param ids 需要删除的负面清单历史记录主键集合
     * @return 结果
     */
    public int deleteLabNegativelistHistoryByIds(Long[] ids);

    /**
     * 删除负面清单历史记录信息
     *
     * @param id 负面清单历史记录主键
     * @return 结果
     */
    public int deleteLabNegativelistHistoryById(Long id);

    public List<LabNegativelistHistory> getExpireTimeData();

    List<LabViolationPageListVO> historypageList(String overStatus, String statTime, String endTime);

    R updateLabHistory(Long violationId, int status);
}
